@@ -405,7 +405,7 @@ float UTopScale()
 
 short UTopTransScale(float length)
 {
-   /* 0.5 gives nearent int but unfortunately gives odd results. . .*/
+   /* 0.5 gives nearest int but unfortunately gives odd results. . .*/
   
    return (short)(length * UTopScale() + 0.45);
 }
@@ -1990,4 +1990,146 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
    if (stack) pop_stack(stack);
 }
 
-/*-------------------------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Recursively run through the current page and find any labels which	*/
+/* are declared to be style LATEX.  If "checkonly" is present, we set	*/
+/* it to TRUE or FALSE depending on whether or not LATEX labels have	*/
+/* been encountered.  If NULL, then we write LATEX output appropriately	*/
+/* to a file named with the page filename + suffix ".tex".		*/
+/*----------------------------------------------------------------------*/
+
+void UDoLatex(objinstptr theinstance, short level, FILE *f,
+	float scale, int tx, int ty, Boolean *checkonly)
+{
+   XPoint	lpos, xlpos;
+   XfPoint	xfpos;
+   labelptr	thislabel;
+   genericptr	*areagen;
+   objectptr	theobject = theinstance->thisobject;
+   char		*ltext;
+   int		lrjust, tbjust;
+
+   UPushCTM();
+   if (level != 0)
+       UPreMultCTM(DCTM, theinstance->position, theinstance->scale,
+			theinstance->rotation);
+
+   /* make parameter substitutions */
+   psubstitute(theinstance);
+
+   /* find all of the elements */
+   
+   for (areagen = theobject->plist; areagen < theobject->plist +
+           theobject->parts; areagen++) {
+
+      switch((*areagen)->type) {
+         case(OBJECT):
+            UDoLatex(TOOBJINST(areagen), level + 1, f, scale, tx, ty, checkonly);
+	    break;
+   
+	 case(LABEL): 
+	    thislabel = TOLABEL(areagen);
+#ifdef SCHEMA
+	    if (level == 0 || thislabel->pin == False ||
+			(thislabel->justify & PINVISIBLE))
+#endif
+		if (thislabel->justify & LATEXLABEL) {
+		    if (checkonly) {
+		       *checkonly = TRUE;
+		       return;
+		    }
+		    else {
+		       lpos.x = thislabel->position.x;
+		       lpos.y = thislabel->position.y;
+		       UTransformbyCTM(DCTM, &lpos, &xlpos, 1);
+		       xlpos.x += tx;
+		       xlpos.y += ty;
+		       xfpos.x = (float)xlpos.x * scale;
+		       xfpos.y = (float)xlpos.y * scale;
+		       xfpos.x /= 72.0;
+		       xfpos.y /= 72.0;
+		       xfpos.x -= 1.0;
+		       xfpos.y -= 1.0;
+		       xfpos.x += 0.056;
+		       xfpos.y += 0.056;
+		       ltext = textprint(thislabel->string, theinstance);
+		       tbjust = thislabel->justify & (NOTBOTTOM | TOP);
+		       lrjust = thislabel->justify & (NOTLEFT | RIGHT);
+		       fprintf(f, "\\putbox{%3.2fin}{%3.2fin}{",
+				xfpos.x, xfpos.y);
+		       if (lrjust == (NOTLEFT | RIGHT)) fprintf(f, "\\rightbox{");
+		       else if (lrjust == NOTLEFT) fprintf(f, "\\centbox{");
+		       if (tbjust == (NOTBOTTOM | TOP)) fprintf(f, "\\topbox{");
+		       else if (tbjust == NOTBOTTOM) fprintf(f, "\\midbox{");
+		       fprintf(f, "%s", ltext);
+		       if (lrjust != NORMAL) fprintf(f, "}");
+		       if (tbjust != NORMAL) fprintf(f, "}");
+		       fprintf(f, "}%%\n");
+		       free(ltext);
+		    }
+		}
+	    break;
+       }
+   }
+   UPopCTM();
+}
+
+/*----------------------------------------------------------------------*/
+/*  Top level routine for writing LATEX output.				*/
+/*----------------------------------------------------------------------*/
+
+void TopDoLatex()
+{
+   FILE *f;
+   float psscale;
+   int tx, ty, width, height;
+   XPoint origin;
+   Boolean checklatex = FALSE;
+   char filename[50];
+
+   UDoLatex(areastruct.topinstance, 0, NULL, 1.0, 0, 0, &checklatex);
+
+   if (checklatex == FALSE) return;	/* No LaTeX labels to write */
+
+   sprintf(filename, "%s.tex", xobjs.pagelist[areastruct.page]->filename);
+   f = fopen(filename, "w");
+
+   fprintf(f, "%% XCircuit output \"%s\" for LaTeX input from %s.ps\n",
+		filename, xobjs.pagelist[areastruct.page]->filename);
+   fprintf(f, "\\def\\putbox#1#2#3{\\makebox[0in][l]{\\makebox[#1][l]{}"
+		"\\raisebox{\\baselineskip}[0in][0in]"
+		"{\\raisebox{#2}[0in][0in]{#3}}}}\n");
+   fprintf(f, "\\def\\rightbox#1{\\makebox[0in][r]{#1}}\n");
+   fprintf(f, "\\def\\centbox#1{\\makebox[0in]{#1}}\n");
+   fprintf(f, "\\def\\topbox#1{\\raisebox{-\\baselineskip}[0in][0in]{#1}}\n");
+   fprintf(f, "\\def\\midbox#1{\\raisebox{-0.5\\baselineskip}[0in][0in]{#1}}\n");
+   fprintf(f, "\\begin{flushleft}\n");
+   fprintf(f, "\\epsfig{file=%s.ps}\\\\\n",
+		xobjs.pagelist[areastruct.page]->filename);
+
+   psscale = getpsscale(xobjs.pagelist[areastruct.page]->outscale,
+		areastruct.page);
+
+#ifdef SCHEMA
+   width = toplevelwidth(areastruct.topinstance, &origin.x);
+   height = toplevelheight(areastruct.topinstance, &origin.y);
+#else
+   width = topobject->bbox.width;
+   height = topobject->bbox.height;
+   origin = topobject->bbox.lowerleft;
+#endif
+
+   tx = (int)(72 / psscale) - origin.x,
+   ty = (int)(72 / psscale) - origin.y;
+
+   fprintf(f, "%% translate x=%d y=%d scale %3.2f\n", tx, ty, psscale);
+
+   UPushCTM();		/* Save current state */
+   UResetCTM(DCTM);	/* Set to identity matrix */
+   UDoLatex(areastruct.topinstance, 0, f, psscale, tx, ty, NULL);
+   UPopCTM();		/* Restore state */
+
+   fprintf(f, "\\end{flushleft}\n");
+   fclose(f);
+}
+
