@@ -73,10 +73,10 @@ static char *function_names[NUM_FUNCTIONS + 1] = {
    "Text Up", "Text Down", "Text Split", 
    "Text Home", "Text End", "Return Char", "Parameter",
    "Parameterize Point", "Break at Point", "Delete Point", "Insert Point",
-   "Next Point", "Attach", "Next Library", "Library Directory",
+   "Append Point", "Next Point", "Attach", "Next Library", "Library Directory",
    "Library Move", "Library Copy", "Library Edit", "Library Delete",
    "Library Duplicate", "Library Hide", "Library Virtual Copy",
-   "Page Directory", "Library Pop",
+   "Page Directory", "Library Pop", "Virtual Copy",
    "Help", "Redraw", "View", "Zoom In", "Zoom Out", "Pan",
    "Double Snap", "Halve Snap", "Pan Left", "Pan Right", "Pan Up",
    "Pan Down", "Write", "Rotate", "Flip X", "Flip Y", "Snap", "Snap To",
@@ -572,6 +572,7 @@ void default_keybindings()
    add_binding(XK_Insert, XCF_Edit_Insert);
    add_binding(XK_e, XCF_Edit_Next);
    add_binding(XK_A, XCF_Attach);
+   add_binding(XK_V, XCF_Virtual);
    add_binding(XK_l, XCF_Next_Library);
    add_binding(XK_L, XCF_Library_Directory);
    add_binding(XK_c, XCF_Library_Copy);
