@@ -158,7 +158,7 @@ proc xcircuit::setpstype {mode} {
 	 grid .output.textent.txtf -row 6 -column 2 -sticky ew -padx 10
       }
    }
-   ::set pstype $mode
+   set pstype $mode
    xcircuit::page encapsulation $mode
 }
 
@@ -196,7 +196,7 @@ proc xcircuit::pageupdate { {subcommand "none"} } {
 	default {
 	  .output.title.field configure -text \
 		"PostScript output properties (Page [xcircuit::page])"
-	  ::set fname [xcircuit::page filename]
+	  set fname [xcircuit::page filename]
 	  .output.textent.but1 configure -text Apply
 	  .output.textent.but2 configure -text Apply
 	  .output.textent.but3 configure -text Apply
@@ -208,11 +208,11 @@ proc xcircuit::pageupdate { {subcommand "none"} } {
 	  .output.textent.txt2 delete 0 end
 	  .output.textent.txt2 insert 0 [xcircuit::page label]
 	  .output.textent.txt3 delete 0 end
-	  ::set oldp $tcl_precision
-	  ::set tcl_precision 5
+	  set oldp $tcl_precision
+	  set tcl_precision 5
 	  .output.textent.txt3 insert 0 [xcircuit::page scale]
 	  .output.textent.txt4 delete 0 end
-	  ::set tcl_precision 3
+	  set tcl_precision 3
 	  .output.textent.txt4 insert 0 [xcircuit::page width]
 	  .output.textent.txt4 insert end " "
 	  .output.textent.txt4 insert end [xcircuit::coordstyle get]
@@ -222,9 +222,9 @@ proc xcircuit::pageupdate { {subcommand "none"} } {
 	  .output.textent.txt5 insert end [xcircuit::coordstyle get]
 	  .output.textent.txtf.txtp delete 0 end
 	  .output.textent.txtf.txtp insert 0 [xcircuit::page size]
-	  ::set tcl_precision $oldp
+	  set tcl_precision $oldp
 	  xcircuit::setpstype [xcircuit::page encapsulation]
-	  ::set orient [xcircuit::page orientation]
+	  set orient [xcircuit::page orientation]
 	  if {$orient == 0} {
 	     .output.textent.buto configure -text Portrait
 	  } else {
@@ -232,7 +232,7 @@ proc xcircuit::pageupdate { {subcommand "none"} } {
 	  }
 	  xcircuit::dolinks
 
-	  ::set autofit [xcircuit::page fit]
+	  set autofit [xcircuit::page fit]
 	  if {[string match *.* $fname] == 0} {append fname .ps}
 	  if {[glob -nocomplain ${fname}] == {}} {
 	    .output.bbar.okay configure -text "Write File"
@@ -875,7 +875,7 @@ proc xcircuit::promptmakesymbol {} {
 }
 
 proc xcircuit::promptobjectsize {} {
-   if {![catch {::set cscale [xcircuit::element [select get] scale]}]} {
+   if {![catch {set cscale [xcircuit::element [select get] scale]}]} {
       .dialog.bbar.okay configure -command \
 	  {xcircuit::instance scale [.dialog.textent.txt get]; \
 	  wm withdraw .dialog}
@@ -900,14 +900,13 @@ proc xcircuit::promptborderwidth {} {
       .dialog.textent.title.field configure -text "Enter default linewidth scale:"
       .dialog.textent.txt insert 0 [xcircuit::border get]
    } else {
-      set eval [lindex $elist 0]
       .dialog.bbar.okay configure -command \
 	   {xcircuit::border set [.dialog.textent.txt get]; \
 	   wm withdraw .dialog}
       .dialog.textent.title.field configure -text "Enter element linewidth:"
-      .dialog.textent.txt insert 0 [xcircuit::element $eval border get]
+      .dialog.textent.txt insert 0 [lindex [xcircuit::border get] 0]
    }
-   ::set tcl_precision $savep
+   set tcl_precision $savep
    wm deiconify .dialog
    focus .dialog.textent.txt
 }
@@ -919,10 +918,10 @@ proc xcircuit::promptlinewidth {} {
 	 wm withdraw .dialog}
    .dialog.textent.title.field configure -text "Enter page linewidth scaling:"
    .dialog.textent.txt delete 0 end
-   ::set savep $tcl_precision
-   ::set tcl_precision 3
+   set savep $tcl_precision
+   set tcl_precision 3
    .dialog.textent.txt insert 0 [xcircuit::config linewidth]
-   ::set tcl_precision $savep
+   set tcl_precision $savep
    wm deiconify .dialog
    focus .dialog.textent.txt
 }
@@ -933,10 +932,10 @@ proc xcircuit::promptdrawingscale {} {
 	{xcircuit::config drawingscale [.dialog.textent.txt get]; wm withdraw .dialog}
    .dialog.textent.title.field configure -text "Enter drawing scale:"
    .dialog.textent.txt delete 0 end
-   ::set savep $tcl_precision
-   ::set tcl_precision 3
+   set savep $tcl_precision
+   set tcl_precision 3
    .dialog.textent.txt insert 0 [xcircuit::config drawingscale]
-   ::set tcl_precision $savep
+   set tcl_precision $savep
    wm deiconify .dialog
    focus .dialog.textent.txt
 }
@@ -947,10 +946,10 @@ proc xcircuit::promptgridspace {} {
 	{xcircuit::config grid spacing [.dialog.textent.txt get]; wm withdraw .dialog}
    .dialog.textent.title.field configure -text "Enter grid spacing:"
    .dialog.textent.txt delete 0 end
-   ::set savep $tcl_precision
-   ::set tcl_precision 3
+   set savep $tcl_precision
+   set tcl_precision 3
    .dialog.textent.txt insert 0 [xcircuit::config grid space]
-   ::set tcl_precision $savep
+   set tcl_precision $savep
    wm deiconify .dialog
    focus .dialog.textent.txt
 }
@@ -961,10 +960,10 @@ proc xcircuit::promptsnapspace {} {
 	{xcircuit::config snap spacing [.dialog.textent.txt get]; wm withdraw .dialog}
    .dialog.textent.title.field configure -text "Enter snap spacing:"
    .dialog.textent.txt delete 0 end
-   ::set savep $tcl_precision
-   ::set tcl_precision 3
+   set savep $tcl_precision
+   set tcl_precision 3
    .dialog.textent.txt insert 0 [xcircuit::config snap space]
-   ::set tcl_precision $savep
+   set tcl_precision $savep
    wm deiconify .dialog
    focus .dialog.textent.txt
 }
@@ -1055,10 +1054,10 @@ proc xcircuit::prompttextsize {} {
 	{xcircuit::label scale [.dialog.textent.txt get]; wm withdraw .dialog}
    .dialog.textent.title.field configure -text "Enter text scale:"
    .dialog.textent.txt delete 0 end
-   ::set savep $tcl_precision
-   ::set tcl_precision 3
+   set savep $tcl_precision
+   set tcl_precision 3
    .dialog.textent.txt insert 0 [xcircuit::label scale]
-   ::set tcl_precision $savep
+   set tcl_precision $savep
    wm deiconify .dialog
    focus .dialog.textent.txt
 }
@@ -1101,9 +1100,9 @@ proc xcircuit::newfontbutton {familyname} {
 proc xcircuit::newlibrarybutton {libname} {
    if {[catch {.xcircuit.menubar.windowbutton.windowmenu.librarymenu \
 		index $libname} result]} {
-      ::set libidx [.xcircuit.menubar.windowbutton.windowmenu.librarymenu \
+      set libidx [.xcircuit.menubar.windowbutton.windowmenu.librarymenu \
 		index end]
-      if {$libidx <= 1} {::set libidx [expr $libidx + 1]}
+      if {$libidx <= 1} {set libidx [expr $libidx + 1]}
       .xcircuit.menubar.windowbutton.windowmenu.librarymenu insert $libidx \
 		command -label $libname -command "xcircuit::library \"$libname\" goto"
    }
@@ -1112,21 +1111,21 @@ proc xcircuit::newlibrarybutton {libname} {
 proc xcircuit::newpagebutton {pagename {pageno 0}} {
    if {[catch {.xcircuit.menubar.windowbutton.windowmenu.pagemenu \
 		index $pagename} result]} {
-      ::set target $pagename
-      if {$pageno > 0} { ::set target $pageno }
+      set target $pagename
+      if {$pageno > 0} { set target $pageno }
       .xcircuit.menubar.windowbutton.windowmenu.pagemenu add command -label \
 	  	$pagename -command "xcircuit::page \"$target\" goto"
    }
 }
 
 proc xcircuit::renamelib {libno libname} {
-   ::set target [expr $libno + 1]
+   set target [expr $libno + 1]
    .xcircuit.menubar.windowbutton.windowmenu.librarymenu entryconfigure \
 		$target -label $libname -command "xcircuit::library \"$libname\" goto"
 }
 
 proc xcircuit::renamepage {pageno pagename} {
-   ::set target [expr $pageno + 1]
+   set target [expr $pageno + 1]
    .xcircuit.menubar.windowbutton.windowmenu.pagemenu entryconfigure \
 		$target -label $pagename -command "xcircuit::page \"$pagename\" goto"
 }
@@ -1161,7 +1160,7 @@ proc xcircuit::xschema {value} {
 	 pack .xcircuit.infobar.symb .xcircuit.infobar.schem \
         	.xcircuit.infobar.message1 -side left -padx 2 -ipadx 6
 	 pack .xcircuit.infobar.message2 -side bottom -padx 2 -ipadx 6 -fill x
-	 ::set midx [.xcircuit.menubar.optionsbutton.optionsmenu \
+	 set midx [.xcircuit.menubar.optionsbutton.optionsmenu \
 		index "Enable XSchema"]
 	 .xcircuit.menubar.optionsbutton.optionsmenu entryconfigure $midx \
 		-command {xcircuit::xschema disable} -label \
@@ -1172,7 +1171,7 @@ proc xcircuit::xschema {value} {
 	 pack forget .xcircuit.menubar.netlistbutton
 	 pack forget .xcircuit.infobar.symb
 	 pack forget .xcircuit.infobar.schem
-	 ::set midx [.xcircuit.menubar.optionsbutton.optionsmenu \
+	 set midx [.xcircuit.menubar.optionsbutton.optionsmenu \
 		index "Disable XSchema"]
 	 .xcircuit.menubar.optionsbutton.optionsmenu entryconfigure $midx \
 		-command {xcircuit::xschema enable} -label \
@@ -1283,7 +1282,7 @@ proc xcircuit::toolbar {value} {
 	 pack forget .xcircuit.mainframe.mainarea
 	 pack .xcircuit.mainframe.toolbar -side right -fill y -padx 2
 	 pack .xcircuit.mainframe.mainarea -expand true -fill both
-	 ::set midx [.xcircuit.menubar.optionsbutton.optionsmenu \
+	 set midx [.xcircuit.menubar.optionsbutton.optionsmenu \
 		index "Enable Toolbar"]
 	 .xcircuit.menubar.optionsbutton.optionsmenu entryconfigure $midx \
 		-command {xcircuit::toolbar disable} -label \
@@ -1292,7 +1291,7 @@ proc xcircuit::toolbar {value} {
       false -
       disable {
 	 pack forget .xcircuit.mainframe.toolbar
-	 ::set midx [.xcircuit.menubar.optionsbutton.optionsmenu \
+	 set midx [.xcircuit.menubar.optionsbutton.optionsmenu \
 		index "Disable Toolbar"]
 	 .xcircuit.menubar.optionsbutton.optionsmenu entryconfigure $midx \
 		-command {xcircuit::toolbar enable} -label \
@@ -1321,6 +1320,7 @@ set fontscript normal
 set gridstyle "fractional inches"
 set flipinvariant true
 set pinvisible false
+set latexmode false
 set colorscheme normal
 set bbox invisible
 set editinplace true
@@ -1427,6 +1427,9 @@ $m add command -label "Parameterize" \
 $m add command -label "Unparameterize" \
 	-command {xcircuit::parameter forget substring}
 $m add separator
+$m add check -label "LaTeX mode" -variable latexmode -onvalue true \
+	-offvalue false -command {xcircuit::label latex $latexmode}
+$m add separator
 $m add command -label "Make Label" -command {xcircuit::label make}
 
 set m2 [menu $m.fontmenu -tearoff 0]
