@@ -2123,7 +2123,7 @@ void toggleencodingmark(int encodingval)
 
 void togglejustmarks(int justvalue)
 {
-   switch(justvalue & (NOTLEFT | RIGHT)) {
+   switch(justvalue & RLJUSTFIELD) {
       case NORMAL: Tcl_SetVar(xcinterp, "jhoriz", "left", TCL_NAMESPACE_ONLY);
 	 break;
       case NOTLEFT: Tcl_SetVar(xcinterp, "jhoriz", "center", TCL_NAMESPACE_ONLY);
@@ -2131,7 +2131,7 @@ void togglejustmarks(int justvalue)
       case RIGHT|NOTLEFT: Tcl_SetVar(xcinterp, "jhoriz", "right", TCL_NAMESPACE_ONLY);
 	 break;
    }
-   switch(justvalue & (NOTBOTTOM | TOP)) {
+   switch(justvalue & TBJUSTFIELD) {
       case NORMAL: Tcl_SetVar(xcinterp, "jvert", "bottom", TCL_NAMESPACE_ONLY);
 	 break;
       case NOTBOTTOM: Tcl_SetVar(xcinterp, "jvert", "middle", TCL_NAMESPACE_ONLY);
@@ -2143,6 +2143,10 @@ void togglejustmarks(int justvalue)
    /* Flip Invariance property */
    Tcl_SetVar(xcinterp, "flipinvariant", (justvalue & FLIPINV) ? "true" : "false",
 	TCL_NAMESPACE_ONLY);
+
+   /* LaTeX mode property */
+   Tcl_SetVar(xcinterp, "latexmode", (justvalue & LATEXLABEL) ? "true" : "false",
+	TCL_NAMESPACE_ONLY);
      
 #ifdef SCHEMA
    /* Pin visibility property */
@@ -2193,14 +2197,14 @@ void setfontmarks(short fvalue, short jvalue)
       togglefontmark(fvalue);
    }
    if (jvalue >= 0) {
-      switch(jvalue & (NOTLEFT | RIGHT)) {
+      switch(jvalue & (RLJUSTFIELD)) {
          case NORMAL: w = JustificationLeftJustifiedButton; break;
          case NOTLEFT: w = JustificationCenterJustifiedButton; break;
          case RIGHT|NOTLEFT: w = JustificationRightJustifiedButton; break;
       }
       toggleexcl(w, Justifs, XtNumber(Justifs));
 
-      switch(jvalue & (NOTBOTTOM | TOP)) {
+      switch(jvalue & (TBJUSTFIELD)) {
          case NORMAL: w = JustificationBottomJustifiedButton; break;
          case NOTBOTTOM: w = JustificationMiddleJustifiedButton; break;
          case TOP|NOTBOTTOM: w = JustificationTopJustifiedButton; break;
@@ -2318,20 +2322,20 @@ void setdefaultfontmarks()
    setfontmarks(areastruct.psfont, areastruct.justify);
 }
 
-/*----------------------------------------------------------------*/
-/* Change flip invariance on the label passed as 2nd parameter	  */
-/*----------------------------------------------------------------*/
+/*--------------------------------------------------------------*/
+/* Toggle a bit in the justification field of a label		*/
+/*--------------------------------------------------------------*/
 
-void doflipflip(xcWidget w, labelptr settext)
+void dojustifybit(xcWidget w, labelptr settext, short bitfield)
 {
    short newjust;
    Boolean boolval;
    u_short value;
 
    if (settext != NULL) {
-      boolval = (settext->justify & FLIPINV) ? True : False;
-      value = boolval ? 0 : FLIPINV;
-      newjust = (settext->justify & (~FLIPINV)) | value;
+      boolval = (settext->justify & bitfield) ? True : False;
+      value = boolval ? 0 : bitfield;
+      newjust = (settext->justify & (~bitfield)) | value;
 
       undrawtext(settext);
       settext->justify = newjust;
@@ -2339,28 +2343,31 @@ void doflipflip(xcWidget w, labelptr settext)
       pwriteback(areastruct.topinstance);
    }
    else {
-      boolval = (areastruct.justify & FLIPINV) ? True : False;
-      value = boolval ? 0 : FLIPINV;
-      newjust = (areastruct.justify & (~FLIPINV)) | value;
+      boolval = (areastruct.justify & bitfield) ? True : False;
+      value = boolval ? 0 : bitfield;
+      newjust = (areastruct.justify & (~bitfield)) | value;
       areastruct.justify = newjust;
    }
    if (w != NULL) toggle(w, &boolval, NULL);
 }
 
-/*----------------------------------------------------------------*/
-/* Change pin visibility on the label passed as 2nd parameter	  */
-/*----------------------------------------------------------------*/
+/*--------------------------------------------------------------*/
+/* Toggle a pin-related bit in the justification field of a	*/
+/* label.  This differs from dojustifybit() in that the label	*/
+/* must be a pin, and this function cannot change the default	*/
+/* behavior set by areastruct.justify.				*/
+/*--------------------------------------------------------------*/
 
-void dopinvisible(xcWidget w, labelptr settext)
+void dopinjustbit(xcWidget w, labelptr settext, short bitfield)
 {
    short newjust;
    Boolean boolval;
    u_short value;
 
    if (settext != NULL && settext->pin) {
-      boolval = (settext->justify & PINVISIBLE) ? True : False;
-      value = boolval ? 0 : PINVISIBLE;
-      newjust = (settext->justify & (~PINVISIBLE)) | value;
+      boolval = (settext->justify & bitfield) ? True : False;
+      value = boolval ? 0 : bitfield;
+      newjust = (settext->justify & (~bitfield)) | value;
 
       undrawtext(settext);
       settext->justify = newjust;
@@ -2381,10 +2388,10 @@ void setjust(xcWidget w, pointertype value, labelptr settext, short mode)
    if (settext != NULL) {
 
       if (mode == 1)
-         newjust = (settext->justify & (PINVISIBLE | FLIPINV | TOP | NOTBOTTOM))
+         newjust = (settext->justify & (NONJUSTFIELD | TBJUSTFIELD))
 			| value;
       else
-         newjust = (settext->justify & (PINVISIBLE | FLIPINV | RIGHT | NOTLEFT))
+         newjust = (settext->justify & (NONJUSTFIELD | RLJUSTFIELD))
 			| value;
 
       undrawtext(settext);
@@ -2394,10 +2401,10 @@ void setjust(xcWidget w, pointertype value, labelptr settext, short mode)
    }
    else {
       if (mode == 1)
-         newjust = (areastruct.justify & (PINVISIBLE | FLIPINV | TOP | NOTBOTTOM))
+         newjust = (areastruct.justify & (NONJUSTFIELD | TBJUSTFIELD))
 			| value;
       else
-         newjust = (areastruct.justify & (PINVISIBLE | FLIPINV | RIGHT | NOTLEFT))
+         newjust = (areastruct.justify & (NONJUSTFIELD | RLJUSTFIELD))
 			| value;
       areastruct.justify = newjust;
    }
@@ -2464,11 +2471,12 @@ void sethjust(xcWidget w, pointertype value, caddr_t nulldata)
    }
 }
 
-/*----------------------------------------------------------------*/
-/* Set flip invariance on all selected labels			  */ 
-/*----------------------------------------------------------------*/
+/*--------------------------------------------------------------*/
+/* Set a justify field bit on all selected labels		*/ 
+/* (flip invariance, latex mode, etc.)				*/
+/*--------------------------------------------------------------*/
 
-void setflipinv(xcWidget w, pointertype value, caddr_t nulldata)
+void setjustbit(xcWidget w, pointertype value, caddr_t nulldata)
 {
    short *fselect;
    labelptr settext;
@@ -2476,7 +2484,7 @@ void setflipinv(xcWidget w, pointertype value, caddr_t nulldata)
 
    if (eventmode == TEXT2_MODE || eventmode == TEXT3_MODE) {
       settext = *((labelptr *)EDITPART);
-      doflipflip(w, settext);
+      dojustifybit(w, settext, (short)value);
    }
    else {
       for (fselect = areastruct.selectlist; fselect < areastruct.selectlist +
@@ -2484,37 +2492,36 @@ void setflipinv(xcWidget w, pointertype value, caddr_t nulldata)
          if (SELECTTYPE(fselect) == LABEL) {
             labelcount++;
             settext = SELTOLABEL(fselect);
-            doflipflip(NULL, settext);
+            dojustifybit(NULL, settext, (short)value);
          }
       }
-      if (labelcount == 0) doflipflip(w, NULL);
+      if (labelcount == 0) dojustifybit(w, NULL, (short)value);
       else objectdeselect();
    }
 }
 
-/*----------------------------------------------------------------*/
-/* Set pin visibility on all selected pins			  */ 
-/*----------------------------------------------------------------*/
+/*--------------------------------------------------------------*/
+/* Set pin-related bit field of "justify" on all selected pins	*/ 
+/* (e.g., pin visibility)					*/
+/*--------------------------------------------------------------*/
 
-void setpinvisible(xcWidget w, pointertype value, caddr_t nulldata)
+void setpinjustbit(xcWidget w, pointertype value, caddr_t nulldata)
 {
    short *fselect;
    labelptr settext;
-   short labelcount = 0;
 
    if (eventmode == TEXT2_MODE || eventmode == TEXT3_MODE) {
       settext = *((labelptr *)EDITPART);
       if (settext->pin)
-	 dopinvisible(w, settext);
+	 dopinjustbit(w, settext, (short)value);
    }
    else {
       for (fselect = areastruct.selectlist; fselect < areastruct.selectlist +
             areastruct.selects; fselect++) {
          if (SELECTTYPE(fselect) == LABEL) {
-            labelcount++;
             settext = SELTOLABEL(fselect);
 	    if (settext->pin)
-               dopinvisible(NULL, settext);
+               dopinjustbit(NULL, settext, (short)value);
          }
       }
       objectdeselect();
@@ -2980,17 +2987,25 @@ void fontencoding(xcWidget w, pointertype value, caddr_t nulldata)
 
 /*----------------------------------------------*/
 /* Generate the table of special characters	*/
+/*						*/
+/* Return FALSE if the edited label is LaTeX-	*/
+/* compatible, since LaTeX text does not	*/
+/* usually contain special characters, but it	*/
+/* does contain a lot of backslashes.		*/
 /*----------------------------------------------*/
 
-void dospecial()
+Boolean dospecial()
 {
    labelptr curlabel;
    int cfont;
 
    curlabel = TOLABEL(EDITPART);
+   if (curlabel->justify & LATEXLABEL) return False;
+
    cfont = findcurfont(textpos, curlabel->string, areastruct.topinstance);
    composefontlib(cfont);
    startcatalog(NULL, FONTLIB, NULL);
+   return True;
 }
 
 /*-------------------------------------------------*/
