@@ -83,7 +83,7 @@ menustruct Justifs[] = {
 	{"Middle Justified", action(setvjust, Number(NOTBOTTOM))},
 	{"Bottom Justified", setaction(setvjust, Number(NORMAL))},
 	{" ", noaction},
-	{"Flip Invariant", setaction(setflipinv, Number(FLIPINV))},
+	{"Flip Invariant", setaction(setjustbit, Number(FLIPINV))},
 };
 	
 menustruct BoxEditStyles[] = {
@@ -183,6 +183,8 @@ menustruct TextMenu[] = {
 	{"Parameterize", action(promptparam, NULL)},
 	{"Unparameterize", action(startunparam, Number(P_SUBSTRING))},
 	{" ", noaction},
+	{"Set LaTeX Mode", action(setjustbit, Number(LATEXLABEL))},
+	{" ", noaction},
 	{"Make Label (t)", action(starttext, Number(NORMAL))},
 };
 
@@ -251,7 +253,7 @@ menustruct SchemaMenu[] = {
 	{"Make Info Pin (I)", action(starttext, Number(INFO))},
 	{"Make Global Pin (G)", action(starttext, Number(GLOBAL))},
 	{"Convert Label to...", submenu(PinConvert)},
-	{"Pin Visibility", action(setpinvisible, Number(PINVISIBLE))},
+	{"Pin Visibility", action(setpinjustbit, Number(PINVISIBLE))},
 /*	{"Make Object Non-Schematic", action(maketrivial, NULL)}, */
 	{"Make Matching Symbol", action(dobeforeswap, NULL)},
 	{"Associate with Symbol", action(startschemassoc, Number(1))},
