@@ -316,6 +316,7 @@ extern void UDrawPolygon(polyptr);
 extern void UDrawArc(arcptr);
 extern void UDrawPath(pathptr);
 extern void UDrawObject(objinstptr, short, int, pushlistptr *);
+extern void TopDoLatex();
 
 /* from help.c: */
 
@@ -470,7 +471,7 @@ extern void border_popup(xcWidget, caddr_t, caddr_t);
 extern void color_popup(xcWidget, caddr_t, caddr_t);
 extern void fill_popup(xcWidget, caddr_t, caddr_t);
 extern void param_popup(xcWidget, caddr_t, caddr_t);
-extern void dospecial(void);
+extern Boolean dospecial(void);
 
 /* from netlist.c: */
 
