@@ -798,9 +798,10 @@ static PyObject *xc_getlibrary(PyObject *self, PyObject *args)
 static PyObject *xc_getobject(PyObject *self, PyObject *args)
 {
    objectptr thisobj = NULL, *libobj;
+   oparamptr ops;
    PyObject *rdict, *dlist, *tpos;
    const char *oname;
-   int i, j, k;
+   int i, j, k, nparam;
 
    if (!PyArg_ParseTuple(args, "s:getobject", &oname))
       return NULL;
@@ -853,18 +854,19 @@ static PyObject *xc_getobject(PyObject *self, PyObject *args)
       PyList_SetItem(dlist, i, PyInt_FromLong((long)(*(thisobj->plist + i))));
    PyDict_SetItem(rdict, PyString_FromString("parts"), dlist);
 
-   if (thisobj->num_params > 0) {
-      dlist = PyList_New(thisobj->num_params);
-      for (i = 0; i < thisobj->num_params; i++) {
-	 if (thisobj->params[i]->type == XC_INT)
+   nparam = get_num_params(thisobj);
+   if (nparam > 0) {
+      dlist = PyList_New(nparams);
+      i = 0;
+      for (ops = thisobj->params; ops != NULL; ops = ops->next) {
+	 i++;
+	 if (ops->type == XC_INT)
+            PyList_SetItem(dlist, i, PyInt_FromLong((long)(ops->parameter.ivalue)));
+	 else if (ops->type == XC_FLOAT)
             PyList_SetItem(dlist, i,
-		PyInt_FromLong((long)(thisobj->params[i]->parameter.ivalue)));
-	 else if (thisobj->params[i]->type == XC_FLOAT)
-            PyList_SetItem(dlist, i,
-		PyFloat_FromDouble((double)(thisobj->params[i]->parameter.fvalue)));
-	 else if (thisobj->params[i]->type == XC_STRING)
-            PyList_SetItem(dlist, i,
-		PyGetStringParts(thisobj->params[i]->parameter.string));
+		PyFloat_FromDouble((double)(ops->parameter.fvalue)));
+	 else if (ops->type == XC_STRING)
+            PyList_SetItem(dlist, i, PyGetStringParts(ops->parameter.string));
       }
       PyDict_SetItem(rdict, PyString_FromString("parameters"), dlist);
    }
