@@ -120,6 +120,37 @@ void doxschema(xcWidget w, pointertype mode, caddr_t calldata)
    if (mode) drawarea(NULL, NULL, NULL);
 }
 
+/*----------------------------------------------------------------------*/
+/* Find the object with the indicated name.				*/
+/*----------------------------------------------------------------------*/
+
+objectptr NameToObject(char *objname, objinstptr *ret_inst, Boolean dopages)
+{
+   int i;
+   liblistptr spec;
+
+   for (i = 0; i < xobjs.numlibs; i++) {
+      for (spec = xobjs.userlibs[i].instlist; spec != NULL; spec = spec->next) {
+         if (!strcmp(objname, spec->thisinst->thisobject->name)) {
+	    *ret_inst = spec->thisinst;
+	    return spec->thisinst->thisobject;
+	 }
+      }
+   }
+
+   if (dopages) {
+      for (i = 0; i < xobjs.pages; i++) {
+	 if (xobjs.pagelist[i]->pageinst == NULL) continue;
+	 if (!strcmp(objname, xobjs.pagelist[i]->pageinst->thisobject->name)) {
+	    *ret_inst = xobjs.pagelist[i]->pageinst;
+	    return xobjs.pagelist[i]->pageinst->thisobject;
+	 }
+      }
+   }
+   
+   return NULL;
+}
+
 /*------------------------------------------------------------------------*/
 /* Ensure that a page name is unique (required for schematic association) */
 /*------------------------------------------------------------------------*/
@@ -247,7 +278,7 @@ int connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
    if (ggen != NULL) {
       if (checkvalid(topobject) == -1) {
          destroynets();
-         createnets();
+         createnets(areastruct.topinstance);
       }
       if ((netid = is_resolved(&ggen, seltop, &nettop)) != 0) {
          /* Fprintf(stdout, "Net ID is %d in object %s\n", netid, nettop->name); */
@@ -629,7 +660,6 @@ void copypinlabel(labelptr pinlab)
       (*newlabel)->color = pinlab->color;
       (*newlabel)->scale = pinlab->scale;
       (*newlabel)->string = stringcopy(pinlab->string);
-      (*newlabel)->num_params = 0;
       (*newlabel)->passed = NULL;
 
       /* place label just outside bounding box, then recompute bbox */
@@ -840,7 +870,6 @@ void swapschem(xcWidget w, pointertype mode, caddr_t calldata)
 	       (*pinlab)->justify = areastruct.justify; 
 	       (*pinlab)->position.x = 0;
 	       (*pinlab)->position.y = topobject->parts * (TEXTHEIGHT + 10);
-	       (*pinlab)->num_params = 0;
 	       (*pinlab)->passed = NULL;
 	       u2u_snap(&((*pinlab)->position));
 	       (*pinlab)->string = stringcopy(lpin->string);
@@ -859,7 +888,8 @@ void swapschem(xcWidget w, pointertype mode, caddr_t calldata)
       /* If symschem matches the last entry on the push stack, then we	*/
       /* pop; otherwise, we push.					*/
 
-      if (areastruct.stack && areastruct.stack->thisinst->thisobject == topobject->symschem) {
+      if (areastruct.stack && areastruct.stack->thisinst->thisobject
+			== topobject->symschem) {
 	 areastruct.topinstance = areastruct.stack->thisinst;
 	 pop_stack(&areastruct.stack);
       }
