@@ -29,11 +29,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#if defined(DARWIN)
-#include <sys/malloc.h>
-#else
-#include <malloc.h>
-#endif
 #include <signal.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -140,12 +135,16 @@ fontinfo *fonts;
 
 extern short eventmode, textpos, help_up;
 extern float version;
+
+#ifndef TCL_WRAPPER
 extern menustruct TopButtons[];
 #ifdef HAVE_XPM
 extern toolbarstruct ToolBar[];
 extern short toolbuttons;
 #endif
 extern short maxbuttons;
+#endif
+
 extern Pixmap helppix;
 extern aliasptr aliastop;
 
@@ -1177,6 +1176,9 @@ void popupprompt(xcWidget button, char *request, char *current, void (*function)
 
     XtAddCallback(cancelbutton, XtNselect, (XtCallbackProc)destroypopup, okaystruct);
 
+    /* Event handler for WM_DELETE_WINDOW message. */
+    XtAddEventHandler(popup, NoEventMask, True, (XtEventHandler)delwin, okaystruct);
+
     if (current != NULL) {   /* A Text Edit widget is required */
        char		*pdptr;
        short		posit;
@@ -1243,8 +1245,8 @@ void writescalevalues(char *scdest, char *xdest, char *ydest)
    psscale = getpsscale(oscale, areastruct.page);
 
 #ifdef SCHEMA
-   width = toplevelwidth(curpage->pageinst);
-   height = toplevelheight(curpage->pageinst);
+   width = toplevelwidth(curpage->pageinst, NULL);
+   height = toplevelheight(curpage->pageinst, NULL);
 #else
    width = topobject->bbox.width;
    height = topobject->bbox.height;
@@ -2200,18 +2202,24 @@ void clientmessagehandler(xcWidget w, caddr_t clientdata, XEvent *event)
 
 #endif
 
+#ifndef TCL_WRAPPER
 /*----------------------------------------------------------------------*/
 /* Event handler for WM_DELETE_WINDOW message.                          */
 /*----------------------------------------------------------------------*/
 
-void delwin(xcWidget w, caddr_t clientdata, XClientMessageEvent *event)
+void delwin(xcWidget w, popupstruct *bstruct, XClientMessageEvent *event)
 {
    if (event->type != ClientMessage)
       return;
 
-   if(event->message_type == wprot && event->data.l[0] == wmprop[0])
-      exit(0);
+   if((event->message_type == wprot) && (event->data.l[0] == wmprop[0])) {
+      if (w == top)
+	 quitcheck(w, NULL, NULL);
+      else
+         destroypopup(w, bstruct, NULL);
+   }
 }
+#endif
 
 /*----------------------------------------------------------------------*/
 /* Preparatory initialization (to be run before setting up the GUI)	*/
@@ -2304,6 +2312,7 @@ void pre_initialize()
    areastruct.boxedit = MANHATTAN;
    areastruct.lastbackground = NULL;
    areastruct.editstack = (objectptr) malloc(sizeof(object));
+   areastruct.stack = NULL;   /* at the top of the hierarchy */
    initmem(areastruct.editstack);
 
 #ifdef SCHEMA
@@ -2324,7 +2333,6 @@ void pre_initialize()
   
    xobjs.delbuffer.library = (objectptr *) malloc(DELBUFSIZE * sizeof(objectptr));
    xobjs.pages = PAGES;
-   xobjs.stack = NULL;   /* at the top of the hierarchy */
 
    fontcount = 0;
    fonts = (fontinfo *) malloc(sizeof(fontinfo));
