@@ -230,9 +230,14 @@ ULPARAM_MODE, UIPARAM_MODE
 #define RIGHT		2
 #define NOTBOTTOM	4
 #define TOP		8
-#define FLIPINV		16	/* 1 if text is flip-invariant */
-#define PINVISIBLE	32	/* 1 if pin visible outside of object */
-#define PINNOOFFSET	64	/* 0 if pin label offset from position */
+#define FLIPINV		16	/* 1 if text is flip-invariant		*/
+#define PINVISIBLE	32	/* 1 if pin visible outside of object	*/
+#define PINNOOFFSET	64	/* 0 if pin label offset from position	*/
+#define LATEXLABEL	128
+
+#define RLJUSTFIELD	3	/* right-left justification bit field	*/
+#define TBJUSTFIELD	12	/* top-bottom justification bit field	*/
+#define NONJUSTFIELD	240	/* everything but justification fields	*/
 
 /*----------------------------------------------------------------------*/
 /* Text string part: types						*/
